@@ -15,20 +15,26 @@ class Version(str, Enum):
     Debian11 = "bullseye"
 
 
-def raspberrypi(version=Version.Debian10):
-    """x86 amd64"""
+def raspberrypi(version=Version.Debian11):
+    sources = open("/etc/apt/sources.list").read()
+
+    for version in Version:
+        if version in sources:
+            break
+
+    print(f"version: {version}")
+
     writer(
         "/etc/apt/sources.list",
-        f"""deb [arch=armhf] http://mirrors.tuna.tsinghua.edu.cn/raspbian/raspbian/ {version} main non-free contrib rpi
+        content=f"""deb [arch=armhf] http://mirrors.tuna.tsinghua.edu.cn/raspbian/raspbian/ {version} main non-free contrib rpi
         deb-src http://mirrors.tuna.tsinghua.edu.cn/raspbian/raspbian/ {version} main non-free contrib rpi
         deb [arch=arm64] http://mirrors.tuna.tsinghua.edu.cn/raspbian/multiarch/ {version} main""",
         read_only=False,
-        official="https://mirrors.tuna.tsinghua.edu.cn/help/raspbian/",
     )
 
     writer(
         "/etc/apt/sources.list.d/raspi.list",
-        "deb http://mirrors.tuna.tsinghua.edu.cn/raspberrypi/ {version} main",
+        content=f"deb http://mirrors.tuna.tsinghua.edu.cn/raspberrypi/ {version} main",
         read_only=False,
         official="https://mirrors.tuna.tsinghua.edu.cn/help/raspbian/",
     )
