@@ -11,16 +11,19 @@ from .render import render_templates
 
 
 class HttpFramework(str, Enum):
-    Iris = ".iris"
+    Echo = ".echo"
     Fiber = ".fiber"
+    Gin = ".gin"
+    Iris = ".iris"
 
 
 class LoggerFramework(str, Enum):
-    Zerolog = ".zerolog"
     Golog = ".golog"
+    Zerolog = ".zerolog"
 
 
 class CommandLineFramework(str, Enum):
+    Cli = ".cli"
     Cobra = ".cobra"
 
 
@@ -31,6 +34,8 @@ class ConfigurationManagementFramework(str, Enum):
 class Combinations(str, Enum):
     c1 = "1"
     c2 = "2"
+    c3 = "3"
+    c4 = "4"
 
     C1 = ";".join(
         [
@@ -50,12 +55,30 @@ class Combinations(str, Enum):
         ]
     )
 
+    C3 = ";".join(
+        [
+            HttpFramework.Echo,
+            CommandLineFramework.Cobra,
+            ConfigurationManagementFramework.Viper,
+        ]
+    )
+
+    C4 = ";".join(
+        [
+            HttpFramework.Gin,
+            LoggerFramework.Zerolog,
+            CommandLineFramework.Cli,
+        ]
+    )
+
     @staticmethod
     def shortcuts(m: str) -> str:
         if m.isalnum():
             return {
                 Combinations.c1: Combinations.C1,
                 Combinations.c2: Combinations.C2,
+                Combinations.c3: Combinations.C3,
+                Combinations.c4: Combinations.C4,
             }.get(m, Combinations.C2)
 
         return m
